Blatantly runs Bayesian latent variable models.
blatentEstimate(
dataMat,
modelText,
priorsList = NULL,
options = blatentControl()
)A blatentModel object (an R6 class).
A data frame containing the data used for the analysis.
A character string that contains the specifications for the model to be run. See blatentSyntax
or more information about syntax formatting.
A list of priors to be placed on parameters of the model. Defaults to NULL. Currently only accepts NULL.
All priors not set in priorsList will be set in options using blatentControl via the
setDefaultPriors function.
A list of options for estimating the model. Use the blatentControl function to specify the options.
See blatentControl for more information and default values.