Used in blatentSyntax to declare latent variables as an unevaluated function call.
Sets specifications used in estimation.
latent(
unit = "rows",
distribution = "bernoulli",
structure = "univariate",
link = "probit",
type = "ordinal",
meanIdentification = NULL,
varianceIdentification = NULL,
joint = NULL,
vars = NULL
)Attaches the unit (person) ID number or label to observations in data. Currently only allows "rows" which indicates each
row of the data is a separate unit in the model. Defaults to "rows".
Specifies the distribution of the latent variable(s) to which the function points. Defaults to "bernoulli".
Distributions currently available are:
"bernoulli": Specifies each variable follows a Bernoulli distribution (structure must be "univariate").
"mvbernoulli": Specifies that set of variables follow a multivariate Bernoulli distribution (structure must be "joint").
Specifies the type of distributional structure for the latent variables. Defaults to "univariate".
Structures current available are:
"univariate": Specifies each variable is modeled using a univariate (marginal or conditional) distribution.
"joint": Specifies that variables are modeled using a joint distribution (distribution must be "mvbernoulli")
Specifies the link function used for any latent variable model where the latent variable is predicted.
Defaults to "probit". Link functions currently available are:
"probit": Uses a probit link function. Available for variables where distribution = "bernoulli" only.
Specifies the type of latent variable to be estimated. Defaults to "ordinal".
Types currently available are:
"ordinal": Specifies that latent variables have ordinal categories. Available for variables where
distribution = "bernoulli" only.
Reserved for future use.
Reserved for future use.
Specifies the name of the joint distribution of latent variables. Defaults to NULL. Used only when
structure is "joint".
Reserved for future use.